Localisation helper for add request id in logger
=======================================================================

.. image:: https://github.com/bigbag/starlette-request-id/workflows/CI/badge.svg
   :target: https://github.com/bigbag/starlette-request-id/actions?query=workflow%3ACI
.. image:: https://img.shields.io/pypi/v/starlette-request-id.svg
   :target: https://pypi.python.org/pypi/starlette-request-id
